from loguru import logger
import os
import sys
from datetime import datetime


# 检查是否存在日志文件夹
if not os.path.exists("logs"):
    os.makedirs("logs")
    
def init_log(log_level="INFO"):
    # 为每个进程创建独立的日志文件，避免多开竞争
    pid = os.getpid()
    timestamp = datetime.now().strftime("%Y-%m-%d_%H-%M-%S_%f")
    log_file = f"logs/nonepyncm.{timestamp}_{pid}.log"
    
    # 设置日志格式
    log_format = "<green>{time:HH:mm:ss.S}</green> <level>[{level}]</level> {message}"
    
    # 移除默认的控制台输出
    logger.remove()

    # 文件日志 - 每个进程独立文件
    logger.add(
        sink=log_file,
        format=log_format,
        level=log_level,
        rotation="1 MB",
        retention="7 days",
        compression="zip",
    )

    # 控制台日志
    logger.add(
        sink=sys.stderr,
        format=log_format,
        level=log_level,
    )
    
    # 绑定进程ID到日志上下文
    logger.configure(extra={"pid": pid})
    
    # 记录启动信息
    logger.debug(f"日志系统初始化完成，PID: {pid}, 日志文件: {os.path.basename(log_file)}")



import sys
import os
import subprocess
from pathlib import Path
import segno
from .log import logger

def open_folder(path: Path):
    """Open folder in file explorer."""
    try:
        if os.name == 'nt':
            os.startfile(str(path))
        elif os.name == 'posix':
            if sys.platform == 'darwin':
                subprocess.run(['open', str(path)])
            else:
                subprocess.run(['xdg-open', str(path)])
    except Exception as e:
        logger.error(f"Failed to open folder: {e}")

def save_qr_and_open(url: str, filename: str = "login_qr.png"):
    """Generate QR code, save to file, and open it."""
    try:
        qr = segno.make_qr(url)
        path = Path(filename)
        qr.save(str(path), scale=10)
        
        # Try to open the file/folder
        open_folder(path.parent) 
        if sys.platform == 'darwin':
             subprocess.run(['open', str(path)])
        elif os.name == 'nt':
             os.startfile(str(path))
             
        # Print to terminal as fallback/convenience
        print("\nScan this QR code:")
        qr.terminal(compact=True)
        print(f"\nQR Code saved to: {path.absolute()}\n")
        
        return path
    except Exception as e:
        logger.error(f"Failed to save QR: {e}")
        return None

def save_raw_qr(data: bytes, filename: str = "login_qr.png"):
    """Save raw QR image bytes to file and open it (used for QQ QR login)."""
    try:
        path = Path(filename)
        path.write_bytes(data)
        open_folder(path.parent)
        if sys.platform == 'darwin':
            subprocess.run(['open', str(path)])
        elif os.name == 'nt':
            os.startfile(str(path))
        print(f"\nQR Code saved to: {path.absolute()}\n")
        return path
    except Exception as e:
        logger.error(f"Failed to save QR: {e}")
        return None



import argparse
import sys
from pathlib import Path

def get_version():
    try:
        if sys.version_info >= (3, 11):
            import tomllib
        else:
            # For older python versions, we might need to fallback or just return a default
            # But project requires >= 3.11
            return "Unknown"
        
        # Assuming app/__main__.py is 2 levels deep from root (app/__main__.py)
        # But wait, __file__ is inside app package.
        # If run from run.py (root), __file__ of this module is .../app/__main__.py
        pyproject_path = Path(__file__).parent.parent / "pyproject.toml"
        if pyproject_path.exists():
            with open(pyproject_path, "rb") as f:
                data = tomllib.load(f)
                return data["project"]["version"]
    except Exception:
        pass
    return "Unknown"

def main():
    parser = argparse.ArgumentParser(description="NonePyNCM CLI")
    parser.add_argument("-v", "--version", action="store_true", help="Show version and exit")
    parser.add_argument("--no-overwrite", action="store_true", help="Do not overwrite existing files")
    parser.add_argument("--use-download-api", action="store_true", help="Use standard download API instead of quality-based API")
    args = parser.parse_args()

    if args.version:
        print(get_version())
        return

    from .utils import init_log
    init_log()

    from .config import config_manager
    from .ui import ui
    from .utils import logger
    
    # Apply runtime config
    if args.no_overwrite:
        config_manager.set_runtime("overwrite", False)
    if args.use_download_api:
        config_manager.set_runtime("use_download_api", True)

    config_manager.ensure_config()
    ui.run()

if __name__ == "__main__":
    main()
